@@ -1,5 +1,4 @@
-from pip_fluigio.__fluig_services_base.interfaces.dataset import \
-    DatasetQueryParams
+from pip_fluigio.__fluig_services_base.interfaces.dataset import DatasetQueryParams
 
 
 class DatasetPropertiers:
